@@ -12,10 +12,7 @@ class meets_ctc_child_identification_requirements(Variable):
         p = parameters(period).gov.irs.credits.ctc
         if p.child_ssn_requirement_applies:
             ssn_card_type = person("ssn_card_type", period)
-            ssn_card_types = ssn_card_type.possible_values
-            citizen = ssn_card_type == ssn_card_types.CITIZEN
-            non_citizen_valid_ead = (
-                ssn_card_type == ssn_card_types.NON_CITIZEN_VALID_EAD
-            )
-            return citizen | non_citizen_valid_ead
+            ssn_card_str = ssn_card_type.decode_to_str()
+            p = parameters(period).gov.irs.credits.ctc
+            return np.isin(ssn_card_str, p.eligible_ssn_card_type)
         return True
